# Hardware Context — stm32f407-motor

## Target Hardware
- **MCU**: STM32F407

## Peripherals
- **SPI1** (9 registers)
- **TIM1** (19 registers)

## Indexed Documents
| Document | Type | Chip | Chunks |
|----------|------|------|--------|
| STM32F407 | svd | STM32F407 | 2962 |
| hardware notes | documentation | STM32F407 | 1 |
| sample | datasheet | STM32F407 | 5 |
